=begin
(c) TIG 2009-2011

import_from_folder.rb

Run the tool by typing
  TIG::import_from_folder
in the Ruby Console or picking 'Import ALL from Folder' from the File menu.
In the dialog that appears navigate to the required Folder and pick one 
File of the 'type' to be imported.
e.g. select any 'geometry' type [some are available for 'Pro' only]
  skp, dwg, dxf, kml, dae, 2ds, dem, ddf
or image files
  png, jpg, tif, psd, tga, bmp
Images are 'imported' differently...  They come in with their width/height 
in inches based on their pixel-size, and they line up along X-axis [red]
ALL files of the 'type' you selected will be imported from that folder 
into the Model.
SKPs produce an extra request on 'placement'...
Progress of each file is shown in the VCB...

v1.0 20091124 First issue.
v1.1 20100305 Image 'import' added.
v1.2 20110529 Module added.
=end
###
require 'sketchup.rb'
###
module TIG

def self.import_from_folder()
  ###
  def self.get_file()
    msg="Import ALL Files: Choose TYPE..."
    Sketchup::set_status_text(msg)
    file=UI.openpanel(msg,"","")
    if not file
      puts "IMPORT ALL - CANCELED."
      Sketchup.send_action("selectSelectionTool:")
      return nil
    else
      file=file.tr("\\","/")
      return file
    end#if
  end
  ###
  def self.get_folder(file)
    folder=File.dirname(file)
    return folder
  end#def
  ###
  def self.get_type(file)
    type=File.extname(file).downcase
    return type
  end#def
  ###
  def self.get_list(folder,type)
    list=[]
    Dir.foreach(folder){|file|list << File.join(folder,file) if File.extname(file).downcase==type}
    return list
  end#def
  ###
  def self.import(type,list)
    ### check for images
    pt=Geom::Point3d.new(0.0,0.0,0.0)
    imgs=[".png",".jpg",".tif",".psd",".tga",".bmp"]
    if imgs.include?(type)
      image=true
    else
      image=false
    end#if
    model=Sketchup.active_model
    model.start_operation("Import ALL from Folder")
    list.each{|file|
      Sketchup::set_status_text("Importing "+File.basename(file))
      if image
        img=model.active_entities.add_image(file,pt,100.0)
        pxw=img.pixelwidth
        pxh=img.pixelheight
        img.size=pxw,pxh
        pt=Geom::Point3d.new(pt.x+pxw,0.0,0.0)
        ### all images go in a line, in X axis
      else
        model.import(file,false)
        unless File.extname(list[0]).downcase==".skp"
        ins=model.definitions[File.basename(file)].instances[0]
        ins.layer=model.layers.add(File.basename(file, ".*"))
      end#if
    }
    model.commit_operation
    self.place?(list)if File.extname(list[0]).downcase==".skp"
    ### only need to place skps - others are placed automatically ?
    Sketchup.send_action("selectSelectionTool:")
    return nil
  end#def
  ###
  def self.place?(list)
    if UI.messagebox("Place ALL 'SKP' Components Imported from Folder ?\n\n\n",MB_YESNO,"")==6
      ### 6=YES 7=NO
      model=Sketchup.active_model
      defs=model.definitions
      model.start_operation("Place ALL Components Imported from Folder")
      list.each{|file|
        puts name=File.basename(file, ".*")
        Sketchup::set_status_text("Placing "+name)
        defn=nil
        defs.each{|d|defn=d if d.name==name}
        if defn
          tr=Geom::Transformation.new(ORIGIN)
          ins=model.active_entities.add_instance(defn,tr)
        end#if
      }
      model.commit_operation
    end#if
  end#def
  ###
  @file=self.get_file()
  return nil if not @file
  @folder=self.get_folder(@file)
  @type=self.get_type(@file)
  @list=self.get_list(@folder,@type)
  self.import(@type,@list)
  ###
end#def import_from_folder

end#module
###

### menu
if not file_loaded?(File.basename(__FILE__))### so only get menu item once...
    UI.menu("File").add_separator ###
    UI.menu("File").add_item("Import ALL from Folder"){TIG::import_from_folder()} ###
end#if ###
file_loaded(File.basename(__FILE__)) ###
